unit Unit1;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ExtCtrls, StdCtrls, Buttons, Gauges, OleCtrls, NETOLib_TLB, Getdir;

type
  TForm1 = class(TForm)
    FilesList: TListBox;
    Label1: TLabel;
    LoadGroup: TRadioGroup;
    ComGroup: TRadioGroup;
    BaudrateGroup: TRadioGroup;
    CurrGauge: TGauge;
    TotalGauge: TGauge;
    Label2: TLabel;
    Pathname: TEdit;
    PathBtn: TSpeedButton;
    AddBtn: TButton;
    RemoveBtn: TButton;
    MsgLabel: TLabel;
    Shape1: TShape;
    StartStopBtn: TButton;
    OpenDialog1: TOpenDialog;
    NetoCtl1: TNetoCtl;
    procedure FormCreate(Sender: TObject);
    procedure AddBtnClick(Sender: TObject);
    procedure RemoveBtnClick(Sender: TObject);
    procedure PathBtnClick(Sender: TObject);
    procedure StartStopBtnClick(Sender: TObject);
    procedure NetoCtl1Progress(Sender: TObject; Current, Total,
      Comport: Smallint);
    procedure NetoCtl1ProtocolMessage(Sender: TObject; msgCode: Smallint;
      const strMessage: WideString; final, Comport: Smallint);
  private
    { Private declarations }
  public
    { Public declarations }
    ProgramPath : String;
  end;

const
  Baudrates : Array[0..5] of Integer = ( 4800, 9600, 19200, 38400, 57600, 115200 );
  cmTypes : Array[0..2] of enumComType = ( comUpload, comDownload, comBoth );
  
var
  Form1: TForm1;

implementation

{$R *.DFM}

procedure TForm1.FormCreate(Sender: TObject);
var
  FullFileName : String;
begin
  FullFileName := ParamStr(0);      //Path + Filename of program
  ProgramPath :=ExtractFilePath(FullFileName);
  Pathname.Text := ProgramPath;
end;

procedure TForm1.AddBtnClick(Sender: TObject);
begin
  if( OpenDialog1.Execute() )then
  begin
    FilesList.Items.AddStrings( OpenDialog1.Files );
  end;
end;

procedure TForm1.RemoveBtnClick(Sender: TObject);
var
   i : Integer;
begin
    if( FilesList.SelCount <= 0 )then
    begin
      Application.MessageBox('No files selected', 'ERROR INFO', MB_OK or MB_ICONERROR );
      Exit;
    end;

    For i := FilesList.Items.Count Downto 1 do
    begin
      if( FilesList.Selected[ i-1 ]) then
        FilesList.Items.Delete( i-1 );
    end;
end;

procedure TForm1.PathBtnClick(Sender: TObject);
begin
  DirectoryFrm.ShowModal();
end;

procedure TForm1.StartStopBtnClick(Sender: TObject);
var
  files : OleVariant;
  i     : Integer;
  str   : String;
begin
  if(  StartStopBtn.Caption = '&Stop' ) then
  begin
    NetoCtl1.StopRunning();
    Exit;
  end;

  MsgLabel.Caption := '';
  Shape1.Brush.Color := clYellow;

  NetoCtl1.Comport := ComGroup.ItemIndex + 1;
  NetoCtl1.Baudrate := Baudrates[ BaudrateGroup.ItemIndex ];
  NetoCtl1.Parity := 0;   { No Parity }
  NetoCtl1.ByteSize := 8; { 8 databits per byte }
  NetoCtl1.StopBits := 0; { 1 StopBit }
  NetoCtl1.PollSpeed := 250;  { 250 ms per poll is 4 polls per second }
  NetoCtl1.PollTimeout := -1; { no timeout }
  NetoCtl1.IrDADevice := NoneIrda; { No irda device connected to the COM port }
  NetoCtl1.RxTxDelay := 1;    { 1 ms delay between sending receiving }

  files := VarArrayCreate( [0, (FilesList.Items.Count)], varOleStr );

  for i := 0 to FilesList.Items.Count-1 do
  begin
    files[i] := FilesList.Items.Strings[i];
  end;

  i := NetoCtl1.UpDownload('&&&&&&', files, Pathname.Text, downOverWrite, cmTypes[ LoadGroup.ItemIndex ]);
  if( i < 0 ) then
  begin
    case i of
      -3: str := 'Pathname is not set';
      -6,-7: str := 'files not set';
      else
        str := 'udefined error';
    end;
    Application.MessageBox( PChar(str), 'Error', MB_OK or MB_ICONERROR );
    exit;
  end;

  StartStopBtn.Caption := '&Stop';
  Shape1.Visible := true;

end;

procedure TForm1.NetoCtl1Progress(Sender: TObject; Current, Total,
  Comport: Smallint);
begin
    if( (Total <> 0) and (Current <> 0) )then
        Shape1.Brush.Color := clLime;
    CurrGauge.Progress := Current;
    TotalGauge.Progress := Total;
end;

procedure TForm1.NetoCtl1ProtocolMessage(Sender: TObject;
  msgCode: Smallint; const strMessage: WideString; final,
  Comport: Smallint);
begin
  MsgLabel.Caption := strMessage;
  if( final = 1 )then
  begin
    StartStopBtn.Caption := '&Start';
    Shape1.Visible := false;
  end;
end;

end.
